aboutsummaryrefslogtreecommitdiffstats
path: root/tests/conftest.py
diff options
context:
space:
mode:
authorAyrx <terrycwk1994@gmail.com>2014-04-16 21:42:11 +0800
committerAyrx <terrycwk1994@gmail.com>2014-04-22 12:11:34 +0800
commitb5bb0653b934bdf5fbf93dc1e5491e78f5c71467 (patch)
tree55219a99d2e440e37f7c5a8ead42b0b3f3c3db4b /tests/conftest.py
parent3080127116dc298271a2768c16173cf591d614ce (diff)
downloadcryptography-b5bb0653b934bdf5fbf93dc1e5491e78f5c71467.tar.gz
cryptography-b5bb0653b934bdf5fbf93dc1e5491e78f5c71467.tar.bz2
cryptography-b5bb0653b934bdf5fbf93dc1e5491e78f5c71467.zip
Added CMAC tests
Diffstat (limited to 'tests/conftest.py')
-rw-r--r--tests/conftest.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/tests/conftest.py b/tests/conftest.py
index 1ee2a993..6ba8ae0a 100644
--- a/tests/conftest.py
+++ b/tests/conftest.py
@@ -17,10 +17,9 @@ import pytest
from cryptography.hazmat.backends import _available_backends
from cryptography.hazmat.backends.interfaces import (
- CipherBackend, DSABackend, HMACBackend, HashBackend, PBKDF2HMACBackend,
- RSABackend
+ CipherBackend, CMACBackend, DSABackend, HMACBackend, HashBackend,
+ PBKDF2HMACBackend, RSABackend
)
-
from .utils import check_backend_support, check_for_iface, select_backends
@@ -36,6 +35,7 @@ def pytest_generate_tests(metafunc):
def pytest_runtest_setup(item):
check_for_iface("hmac", HMACBackend, item)
check_for_iface("cipher", CipherBackend, item)
+ check_for_iface("cmac", CMACBackend, item)
check_for_iface("hash", HashBackend, item)
check_for_iface("pbkdf2hmac", PBKDF2HMACBackend, item)
check_for_iface("dsa", DSABackend, item)